import { IRole } from 'aws-cdk-lib/aws-iam';
import { Resource, IResource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IIdentityPool, IdentityPoolProviderUrl } from './identitypool';
/**
 * (experimental) Represents an Identity Pool Role Attachment.
 *
 * @experimental
 */
export interface IIdentityPoolRoleAttachment extends IResource {
    /**
     * (experimental) Id of the Attachments Underlying Identity Pool.
     *
     * @experimental
     */
    readonly identityPoolId: string;
}
/**
 * (experimental) Props for an Identity Pool Role Attachment.
 *
 * @experimental
 */
export interface IdentityPoolRoleAttachmentProps {
    /**
     * (experimental) Id of the Attachments Underlying Identity Pool.
     *
     * @experimental
     */
    readonly identityPool: IIdentityPool;
    /**
     * (experimental) Default Authenticated (User) Role.
     *
     * @default - No default authenticated role will be added
     * @experimental
     */
    readonly authenticatedRole?: IRole;
    /**
     * (experimental) Default Unauthenticated (Guest) Role.
     *
     * @default - No default unauthenticated role will be added
     * @experimental
     */
    readonly unauthenticatedRole?: IRole;
    /**
     * (experimental) Rules for mapping roles to users.
     *
     * @default - no Role Mappings
     * @experimental
     */
    readonly roleMappings?: IdentityPoolRoleMapping[];
}
/**
 * (experimental) Map roles to users in the identity pool based on claims from the Identity Provider.
 *
 * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cognito-identitypoolroleattachment.html
 * @experimental
 */
export interface IdentityPoolRoleMapping {
    /**
     * (experimental) The url of the provider of for which the role is mapped.
     *
     * @experimental
     */
    readonly providerUrl: IdentityPoolProviderUrl;
    /**
     * (experimental) If true then mapped roles must be passed through the cognito:roles or cognito:preferred_role claims from identity provider.
     *
     * @default false
     * @see https://docs.aws.amazon.com/cognito/latest/developerguide/role-based-access-control.html#using-tokens-to-assign-roles-to-users
     * @experimental
     */
    readonly useToken?: boolean;
    /**
     * (experimental) Allow for role assumption when results of role mapping are ambiguous.
     *
     * @default false - Ambiguous role resolutions will lead to requester being denied
     * @experimental
     */
    readonly resolveAmbiguousRoles?: boolean;
    /**
     * (experimental) The claim and value that must be matched in order to assume the role.
     *
     * Required if useToken is false
     *
     * @default - No Rule Mapping Rule
     * @experimental
     */
    readonly rules?: RoleMappingRule[];
}
/**
 * (experimental) Types of matches allowed for Role Mapping.
 *
 * @experimental
 */
export declare enum RoleMappingMatchType {
    /**
     * (experimental) The Claim from the token must equal the given value in order for a match.
     *
     * @experimental
     */
    EQUALS = "Equals",
    /**
     * (experimental) The Claim from the token must contain the given value in order for a match.
     *
     * @experimental
     */
    CONTAINS = "Contains",
    /**
     * (experimental) The Claim from the token must start with the given value in order for a match.
     *
     * @experimental
     */
    STARTS_WITH = "StartsWith",
    /**
     * (experimental) The Claim from the token must not equal the given value in order for a match.
     *
     * @experimental
     */
    NOTEQUAL = "NotEqual"
}
/**
 * (experimental) Represents an Identity Pool Role Attachment Role Mapping Rule.
 *
 * @experimental
 */
export interface RoleMappingRule {
    /**
     * (experimental) The key sent in the token by the federated identity provider.
     *
     * @experimental
     */
    readonly claim: string;
    /**
     * (experimental) The Role to be assumed when Claim Value is matched.
     *
     * @experimental
     */
    readonly mappedRole: IRole;
    /**
     * (experimental) The value of the claim that must be matched.
     *
     * @experimental
     */
    readonly claimValue: string;
    /**
     * (experimental) How to match with the Claim value.
     *
     * @default RoleMappingMatchType.EQUALS
     * @experimental
     */
    readonly matchType?: RoleMappingMatchType;
}
/**
 * (experimental) Defines an Identity Pool Role Attachment.
 *
 * @experimental
 * @resource AWS::Cognito::IdentityPoolRoleAttachment
 */
export declare class IdentityPoolRoleAttachment extends Resource implements IIdentityPoolRoleAttachment {
    /**
     * (experimental) Id of the underlying identity pool.
     *
     * @experimental
     */
    readonly identityPoolId: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: IdentityPoolRoleAttachmentProps);
    /**
     * Configures Role Mappings for Identity Pool Role Attachment
     */
    private configureRoleMappings;
}
